# FastBay

FastBay allows it's users to find the top result in PirateBay search and get it's link for a download.

This is a fast way of finding the file you need, not opening your browser.
You just need to enter the keyword and it will bring the top result's Information, as well as a Magnet Link, so you are able to download the file. 

Sometimes you may notice, that it is not possible to download the torrent as it is loading forever. That's a problem of either PirateBay or the user who uploaded the torrent. In such case try "playing" with keywords, so you will get the result you want.
